# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import common_messages_pb2 as protos_dot_common__messages__pb2
from . import logicmodule_messages_pb2 as protos_dot_logicmodule__messages__pb2


class LogicModuleStub(object):
    """Interface exported by the server.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.autoregisterSL = channel.unary_unary(
                '/protos.logicmodule.LogicModule/autoregisterSL',
                request_serializer=protos_dot_logicmodule__messages__pb2.AutoRegisterSLRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.autoregisterEE = channel.unary_unary(
                '/protos.logicmodule.LogicModule/autoregisterEE',
                request_serializer=protos_dot_logicmodule__messages__pb2.AutoRegisterEERequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.AutoRegisterEEResponse.FromString,
                )
        self.unregisterStorageLocation = channel.unary_unary(
                '/protos.logicmodule.LogicModule/unregisterStorageLocation',
                request_serializer=protos_dot_logicmodule__messages__pb2.UnregisterStorageLocationRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.unregisterExecutionEnvironment = channel.unary_unary(
                '/protos.logicmodule.LogicModule/unregisterExecutionEnvironment',
                request_serializer=protos_dot_logicmodule__messages__pb2.UnregisterExecutionEnvironmentRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.checkAlive = channel.unary_unary(
                '/protos.logicmodule.LogicModule/checkAlive',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.notifyExecutionEnvironmentShutdown = channel.unary_unary(
                '/protos.logicmodule.LogicModule/notifyExecutionEnvironmentShutdown',
                request_serializer=protos_dot_logicmodule__messages__pb2.NotifyExecutionEnvironmentShutdownRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.notifyStorageLocationShutdown = channel.unary_unary(
                '/protos.logicmodule.LogicModule/notifyStorageLocationShutdown',
                request_serializer=protos_dot_logicmodule__messages__pb2.NotifyStorageLocationShutdownRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.existsActiveEnvironmentsForSL = channel.unary_unary(
                '/protos.logicmodule.LogicModule/existsActiveEnvironmentsForSL',
                request_serializer=protos_dot_logicmodule__messages__pb2.ExistsActiveEnvironmentsForSLRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.ExistsActiveEnvironmentsForSLResponse.FromString,
                )
        self.performSetOfNewAccounts = channel.unary_unary(
                '/protos.logicmodule.LogicModule/performSetOfNewAccounts',
                request_serializer=protos_dot_logicmodule__messages__pb2.PerformSetAccountsRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.PerformSetAccountsResponse.FromString,
                )
        self.performSetOfOperations = channel.unary_unary(
                '/protos.logicmodule.LogicModule/performSetOfOperations',
                request_serializer=protos_dot_logicmodule__messages__pb2.PerformSetOperationsRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.PerformSetOperationsResponse.FromString,
                )
        self.publishAddress = channel.unary_unary(
                '/protos.logicmodule.LogicModule/publishAddress',
                request_serializer=protos_dot_logicmodule__messages__pb2.PublishAddressRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.newAccountNoAdmin = channel.unary_unary(
                '/protos.logicmodule.LogicModule/newAccountNoAdmin',
                request_serializer=protos_dot_logicmodule__messages__pb2.NewAccountNoAdminRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.NewAccountResponse.FromString,
                )
        self.newAccount = channel.unary_unary(
                '/protos.logicmodule.LogicModule/newAccount',
                request_serializer=protos_dot_logicmodule__messages__pb2.NewAccountRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.NewAccountResponse.FromString,
                )
        self.getAccountID = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getAccountID',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetAccountIDRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetAccountIDResponse.FromString,
                )
        self.getAccountList = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getAccountList',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetAccountListRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetAccountListResponse.FromString,
                )
        self.newSession = channel.unary_unary(
                '/protos.logicmodule.LogicModule/newSession',
                request_serializer=protos_dot_logicmodule__messages__pb2.NewSessionRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.NewSessionResponse.FromString,
                )
        self.getInfoOfSessionForDS = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getInfoOfSessionForDS',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetInfoOfSessionForDSRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetInfoOfSessionForDSResponse.FromString,
                )
        self.newNamespace = channel.unary_unary(
                '/protos.logicmodule.LogicModule/newNamespace',
                request_serializer=protos_dot_logicmodule__messages__pb2.NewNamespaceRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.NewNamespaceResponse.FromString,
                )
        self.removeNamespace = channel.unary_unary(
                '/protos.logicmodule.LogicModule/removeNamespace',
                request_serializer=protos_dot_logicmodule__messages__pb2.RemoveNamespaceRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getNamespaceID = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getNamespaceID',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetNamespaceIDRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetNamespaceIDResponse.FromString,
                )
        self.getNamespaceLang = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getNamespaceLang',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetNamespaceLangRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetNamespaceLangResponse.FromString,
                )
        self.getObjectDataSetID = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getObjectDataSetID',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetObjectDataSetIDRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetObjectDataSetIDResponse.FromString,
                )
        self.importInterface = channel.unary_unary(
                '/protos.logicmodule.LogicModule/importInterface',
                request_serializer=protos_dot_logicmodule__messages__pb2.ImportInterfaceRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.importContract = channel.unary_unary(
                '/protos.logicmodule.LogicModule/importContract',
                request_serializer=protos_dot_logicmodule__messages__pb2.ImportContractRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getInfoOfClassesInNamespace = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getInfoOfClassesInNamespace',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetInfoOfClassesInNamespaceRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetInfoOfClassesInNamespaceResponse.FromString,
                )
        self.getImportedClassesInfoInNamespace = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getImportedClassesInfoInNamespace',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetImportedClassesInfoInNamespaceRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetImportedClassesInfoInNamespaceResponse.FromString,
                )
        self.getClassIDfromImport = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getClassIDfromImport',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetClassIDFromImportRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetClassIDFromImportResponse.FromString,
                )
        self.getNamespaces = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getNamespaces',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetNamespacesRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetNamespacesResponse.FromString,
                )
        self.newDataSet = channel.unary_unary(
                '/protos.logicmodule.LogicModule/newDataSet',
                request_serializer=protos_dot_logicmodule__messages__pb2.NewDataSetRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.NewDataSetResponse.FromString,
                )
        self.removeDataSet = channel.unary_unary(
                '/protos.logicmodule.LogicModule/removeDataSet',
                request_serializer=protos_dot_logicmodule__messages__pb2.RemoveDataSetRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getDataSetID = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getDataSetID',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetDataSetIDRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetDataSetIDResponse.FromString,
                )
        self.checkDataSetIsPublic = channel.unary_unary(
                '/protos.logicmodule.LogicModule/checkDataSetIsPublic',
                request_serializer=protos_dot_logicmodule__messages__pb2.CheckDataSetIsPublicRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.CheckDataSetIsPublicResponse.FromString,
                )
        self.getPublicDataSets = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getPublicDataSets',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetPublicDataSetsRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetPublicDataSetsResponse.FromString,
                )
        self.getAccountDataSets = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getAccountDataSets',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetAccountDataSetsRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetAccountDataSetsResponse.FromString,
                )
        self.newClass = channel.unary_unary(
                '/protos.logicmodule.LogicModule/newClass',
                request_serializer=protos_dot_logicmodule__messages__pb2.NewClassRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.NewClassResponse.FromString,
                )
        self.removeClass = channel.unary_unary(
                '/protos.logicmodule.LogicModule/removeClass',
                request_serializer=protos_dot_logicmodule__messages__pb2.RemoveClassRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.removeOperation = channel.unary_unary(
                '/protos.logicmodule.LogicModule/removeOperation',
                request_serializer=protos_dot_logicmodule__messages__pb2.RemoveOperationRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.removeImplementation = channel.unary_unary(
                '/protos.logicmodule.LogicModule/removeImplementation',
                request_serializer=protos_dot_logicmodule__messages__pb2.RemoveImplementationRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getOperationID = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getOperationID',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetOperationIDRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetOperationIDResponse.FromString,
                )
        self.getPropertyID = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getPropertyID',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetPropertyIDRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetPropertyIDResponse.FromString,
                )
        self.getClassID = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getClassID',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetClassIDRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetClassIDResponse.FromString,
                )
        self.getClassInfo = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getClassInfo',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetClassInfoRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetClassInfoResponse.FromString,
                )
        self.newContract = channel.unary_unary(
                '/protos.logicmodule.LogicModule/newContract',
                request_serializer=protos_dot_logicmodule__messages__pb2.NewContractRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.NewContractResponse.FromString,
                )
        self.registerToPublicContract = channel.unary_unary(
                '/protos.logicmodule.LogicModule/registerToPublicContract',
                request_serializer=protos_dot_logicmodule__messages__pb2.RegisterToPublicContractRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.registerToPublicContractOfNamespace = channel.unary_unary(
                '/protos.logicmodule.LogicModule/registerToPublicContractOfNamespace',
                request_serializer=protos_dot_logicmodule__messages__pb2.RegisterToPublicContractOfNamespaceRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.RegisterToPublicContractOfNamespaceResponse.FromString,
                )
        self.getContractIDsOfApplicant = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getContractIDsOfApplicant',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetContractIDsOfApplicantRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetContractIDsOfApplicantResponse.FromString,
                )
        self.getContractIDsOfProvider = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getContractIDsOfProvider',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetContractIDsOfProviderRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetContractIDsOfProviderResponse.FromString,
                )
        self.getContractIDsOfApplicantWithProvider = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getContractIDsOfApplicantWithProvider',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetContractsOfApplicantWithProvRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetContractsOfApplicantWithProvResponse.FromString,
                )
        self.newDataContract = channel.unary_unary(
                '/protos.logicmodule.LogicModule/newDataContract',
                request_serializer=protos_dot_logicmodule__messages__pb2.NewDataContractRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.NewDataContractResponse.FromString,
                )
        self.registerToPublicDataContract = channel.unary_unary(
                '/protos.logicmodule.LogicModule/registerToPublicDataContract',
                request_serializer=protos_dot_logicmodule__messages__pb2.RegisterToPublicDataContractRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getDataContractIDsOfApplicant = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getDataContractIDsOfApplicant',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetDataContractIDsOfApplicantRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetDataContractIDsOfApplicantResponse.FromString,
                )
        self.getDataContractIDsOfProvider = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getDataContractIDsOfProvider',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetDataContractIDsOfProviderRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetDataContractIDsOfProviderResponse.FromString,
                )
        self.getDataContractInfoOfApplicantWithProvider = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getDataContractInfoOfApplicantWithProvider',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetDataContractInfoOfApplicantWithProvRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetDataContractInfoOfApplicantWithProvResponse.FromString,
                )
        self.newInterface = channel.unary_unary(
                '/protos.logicmodule.LogicModule/newInterface',
                request_serializer=protos_dot_logicmodule__messages__pb2.NewInterfaceRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.NewInterfaceResponse.FromString,
                )
        self.getInterfaceInfo = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getInterfaceInfo',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetInterfaceInfoRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetInterfaceInfoResponse.FromString,
                )
        self.removeInterface = channel.unary_unary(
                '/protos.logicmodule.LogicModule/removeInterface',
                request_serializer=protos_dot_logicmodule__messages__pb2.RemoveInterfaceRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getAllExecutionEnvironmentsInfo = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getAllExecutionEnvironmentsInfo',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetAllExecutionEnvironmentsInfoRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetAllExecutionEnvironmentsInfoResponse.FromString,
                )
        self.getStorageLocationID = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getStorageLocationID',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetStorageLocationIDRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetStorageLocationIDResponse.FromString,
                )
        self.getStorageLocationInfo = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getStorageLocationInfo',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetStorageLocationInfoRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetStorageLocationInfoResponse.FromString,
                )
        self.getExecutionEnvironmentInfo = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getExecutionEnvironmentInfo',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetExecutionEnvironmentInfoRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetExecutionEnvironmentInfoResponse.FromString,
                )
        self.getObjectInfo = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getObjectInfo',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetObjectInfoRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetObjectInfoResponse.FromString,
                )
        self.getObjectFromAlias = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getObjectFromAlias',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetObjectFromAliasRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetObjectFromAliasResponse.FromString,
                )
        self.deleteAlias = channel.unary_unary(
                '/protos.logicmodule.LogicModule/deleteAlias',
                request_serializer=protos_dot_logicmodule__messages__pb2.DeleteAliasRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.DeleteAliasResponse.FromString,
                )
        self.getObjectsMetaDataInfoOfClassForNM = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getObjectsMetaDataInfoOfClassForNM',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetObjectsMetaDataInfoOfClassForNMRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetObjectsMetaDataInfoOfClassForNMResponse.FromString,
                )
        self.addAlias = channel.unary_unary(
                '/protos.logicmodule.LogicModule/addAlias',
                request_serializer=protos_dot_logicmodule__messages__pb2.AddAliasRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.registerObjectFromGC = channel.unary_unary(
                '/protos.logicmodule.LogicModule/registerObjectFromGC',
                request_serializer=protos_dot_logicmodule__messages__pb2.RegisterObjectForGCRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.unregisterObjects = channel.unary_unary(
                '/protos.logicmodule.LogicModule/unregisterObjects',
                request_serializer=protos_dot_logicmodule__messages__pb2.UnregisterObjectsRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.registerObjects = channel.unary_unary(
                '/protos.logicmodule.LogicModule/registerObjects',
                request_serializer=protos_dot_logicmodule__messages__pb2.RegisterObjectsRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.RegisterObjectsResponse.FromString,
                )
        self.setDataSetIDFromGarbageCollector = channel.unary_unary(
                '/protos.logicmodule.LogicModule/setDataSetIDFromGarbageCollector',
                request_serializer=protos_dot_logicmodule__messages__pb2.SetDataSetIDFromGarbageCollectorRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getMetadataByOID = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getMetadataByOID',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetMetadataByOIDRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetMetadataByOIDResponse.FromString,
                )
        self.getNumObjects = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getNumObjects',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.GetNumObjectsResponse.FromString,
                )
        self.setDataSetID = channel.unary_unary(
                '/protos.logicmodule.LogicModule/setDataSetID',
                request_serializer=protos_dot_logicmodule__messages__pb2.SetDataSetIDRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.moveObject = channel.unary_unary(
                '/protos.logicmodule.LogicModule/moveObject',
                request_serializer=protos_dot_logicmodule__messages__pb2.MoveObjectRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.MoveObjectResponse.FromString,
                )
        self.setObjectReadOnly = channel.unary_unary(
                '/protos.logicmodule.LogicModule/setObjectReadOnly',
                request_serializer=protos_dot_logicmodule__messages__pb2.SetObjectReadOnlyRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.setObjectReadWrite = channel.unary_unary(
                '/protos.logicmodule.LogicModule/setObjectReadWrite',
                request_serializer=protos_dot_logicmodule__messages__pb2.SetObjectReadWriteRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.executeImplementation = channel.unary_unary(
                '/protos.logicmodule.LogicModule/executeImplementation',
                request_serializer=protos_dot_logicmodule__messages__pb2.ExecuteImplementationRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.ExecuteImplementationResponse.FromString,
                )
        self.executeMethodOnTarget = channel.unary_unary(
                '/protos.logicmodule.LogicModule/executeMethodOnTarget',
                request_serializer=protos_dot_logicmodule__messages__pb2.ExecuteMethodOnTargetRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.ExecuteMethodOnTargetResponse.FromString,
                )
        self.getDataClayID = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getDataClayID',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetDataClayIDResponse.FromString,
                )
        self.registerExternalDataClay = channel.unary_unary(
                '/protos.logicmodule.LogicModule/registerExternalDataClay',
                request_serializer=protos_dot_logicmodule__messages__pb2.RegisterExternalDataClayRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.RegisterExternalDataClayResponse.FromString,
                )
        self.registerExternalDataClayOverrideAuthority = channel.unary_unary(
                '/protos.logicmodule.LogicModule/registerExternalDataClayOverrideAuthority',
                request_serializer=protos_dot_logicmodule__messages__pb2.RegisterExternalDataClayOverrideAuthorityRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.RegisterExternalDataClayResponse.FromString,
                )
        self.notifyRegistrationOfExternalDataClay = channel.unary_unary(
                '/protos.logicmodule.LogicModule/notifyRegistrationOfExternalDataClay',
                request_serializer=protos_dot_logicmodule__messages__pb2.NotifyRegistrationOfExternalDataClayRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.NotifyRegistrationOfExternalDataClayResponse.FromString,
                )
        self.getExternalDataClayInfo = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getExternalDataClayInfo',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetExtDataClayInfoRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetExtDataClayInfoResponse.FromString,
                )
        self.getExternalDataclayId = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getExternalDataclayId',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetExternalDataclayIDRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetExternalDataclayIDResponse.FromString,
                )
        self.getClassesInNamespace = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getClassesInNamespace',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetClassesInNamespaceRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetClassesInNamespaceResponse.FromString,
                )
        self.importModelsFromExternalDataClay = channel.unary_unary(
                '/protos.logicmodule.LogicModule/importModelsFromExternalDataClay',
                request_serializer=protos_dot_logicmodule__messages__pb2.ImportModelsFromExternalDataClayRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getStubs = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getStubs',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetStubsRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetStubsResponse.FromString,
                )
        self.getBabelStubs = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getBabelStubs',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetBabelStubsRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetBabelStubsResponse.FromString,
                )
        self.registerECA = channel.unary_unary(
                '/protos.logicmodule.LogicModule/registerECA',
                request_serializer=protos_dot_logicmodule__messages__pb2.RegisterECARequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.adviseEvent = channel.unary_unary(
                '/protos.logicmodule.LogicModule/adviseEvent',
                request_serializer=protos_dot_logicmodule__messages__pb2.AdviseEventRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.isPrefetchingEnabled = channel.unary_unary(
                '/protos.logicmodule.LogicModule/isPrefetchingEnabled',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.IsPrefetchingEnabledResponse.FromString,
                )
        self.getClassNameForDS = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getClassNameForDS',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetClassNameForDSRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetClassNameForDSResponse.FromString,
                )
        self.getClassNameAndNamespaceForDS = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getClassNameAndNamespaceForDS',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetClassNameAndNamespaceForDSRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetClassNameAndNamespaceForDSResponse.FromString,
                )
        self.getContractIDOfDataClayProvider = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getContractIDOfDataClayProvider',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetContractIDOfDataClayProviderRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetContractIDOfDataClayProviderResponse.FromString,
                )
        self.objectExistsInDataClay = channel.unary_unary(
                '/protos.logicmodule.LogicModule/objectExistsInDataClay',
                request_serializer=protos_dot_logicmodule__messages__pb2.ObjectExistsInDataClayRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.ObjectExistsInDataClayResponse.FromString,
                )
        self.closeSession = channel.unary_unary(
                '/protos.logicmodule.LogicModule/closeSession',
                request_serializer=protos_dot_logicmodule__messages__pb2.CloseSessionRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getMetadataByOIDForDS = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getMetadataByOIDForDS',
                request_serializer=protos_dot_logicmodule__messages__pb2.GetMetadataByOIDForDSRequest.SerializeToString,
                response_deserializer=protos_dot_logicmodule__messages__pb2.GetMetadataByOIDForDSResponse.FromString,
                )
        self.activateTracing = channel.unary_unary(
                '/protos.logicmodule.LogicModule/activateTracing',
                request_serializer=protos_dot_logicmodule__messages__pb2.ActivateTracingRequest.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.deactivateTracing = channel.unary_unary(
                '/protos.logicmodule.LogicModule/deactivateTracing',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.getTraces = channel.unary_unary(
                '/protos.logicmodule.LogicModule/getTraces',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.GetTracesResponse.FromString,
                )
        self.cleanMetaDataCaches = channel.unary_unary(
                '/protos.logicmodule.LogicModule/cleanMetaDataCaches',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.closeManagerDb = channel.unary_unary(
                '/protos.logicmodule.LogicModule/closeManagerDb',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )
        self.closeDb = channel.unary_unary(
                '/protos.logicmodule.LogicModule/closeDb',
                request_serializer=protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
                response_deserializer=protos_dot_common__messages__pb2.ExceptionInfo.FromString,
                )


class LogicModuleServicer(object):
    """Interface exported by the server.
    """

    def autoregisterSL(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def autoregisterEE(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def unregisterStorageLocation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def unregisterExecutionEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def checkAlive(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def notifyExecutionEnvironmentShutdown(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def notifyStorageLocationShutdown(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def existsActiveEnvironmentsForSL(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def performSetOfNewAccounts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def performSetOfOperations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def publishAddress(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def newAccountNoAdmin(self, request, context):
        """Account Manager
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def newAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getAccountID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getAccountList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def newSession(self, request, context):
        """Session Manager
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getInfoOfSessionForDS(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def newNamespace(self, request, context):
        """Namespace Manager
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def removeNamespace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getNamespaceID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getNamespaceLang(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getObjectDataSetID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def importInterface(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def importContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getInfoOfClassesInNamespace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getImportedClassesInfoInNamespace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getClassIDfromImport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getNamespaces(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def newDataSet(self, request, context):
        """DataSet Manager
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def removeDataSet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getDataSetID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def checkDataSetIsPublic(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getPublicDataSets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getAccountDataSets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def newClass(self, request, context):
        """Class Manager
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def removeClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def removeOperation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def removeImplementation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getOperationID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getPropertyID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getClassID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getClassInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def newContract(self, request, context):
        """Contract Manager
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerToPublicContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerToPublicContractOfNamespace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getContractIDsOfApplicant(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getContractIDsOfProvider(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getContractIDsOfApplicantWithProvider(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def newDataContract(self, request, context):
        """DataContract Manager
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerToPublicDataContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getDataContractIDsOfApplicant(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getDataContractIDsOfProvider(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getDataContractInfoOfApplicantWithProvider(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def newInterface(self, request, context):
        """Interface Manager
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getInterfaceInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def removeInterface(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getAllExecutionEnvironmentsInfo(self, request, context):
        """EE-SL information
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getStorageLocationID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getStorageLocationInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getExecutionEnvironmentInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getObjectInfo(self, request, context):
        """Object Metadata
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getObjectFromAlias(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteAlias(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getObjectsMetaDataInfoOfClassForNM(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def addAlias(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerObjectFromGC(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def unregisterObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setDataSetIDFromGarbageCollector(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getMetadataByOID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getNumObjects(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setDataSetID(self, request, context):
        """Storage Location
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def moveObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setObjectReadOnly(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setObjectReadWrite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def executeImplementation(self, request, context):
        """Execution Environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def executeMethodOnTarget(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getDataClayID(self, request, context):
        """Federation 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerExternalDataClay(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerExternalDataClayOverrideAuthority(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def notifyRegistrationOfExternalDataClay(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getExternalDataClayInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getExternalDataclayId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getClassesInNamespace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def importModelsFromExternalDataClay(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getStubs(self, request, context):
        """Stubs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getBabelStubs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def registerECA(self, request, context):
        """Notification Manager
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def adviseEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def isPrefetchingEnabled(self, request, context):
        """Prefetching 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getClassNameForDS(self, request, context):
        """Others
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getClassNameAndNamespaceForDS(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getContractIDOfDataClayProvider(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def objectExistsInDataClay(self, request, context):
        """Testing
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def closeSession(self, request, context):
        """Others
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getMetadataByOIDForDS(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def activateTracing(self, request, context):
        """Paraver
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deactivateTracing(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getTraces(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def cleanMetaDataCaches(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def closeManagerDb(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def closeDb(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LogicModuleServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'autoregisterSL': grpc.unary_unary_rpc_method_handler(
                    servicer.autoregisterSL,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.AutoRegisterSLRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'autoregisterEE': grpc.unary_unary_rpc_method_handler(
                    servicer.autoregisterEE,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.AutoRegisterEERequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.AutoRegisterEEResponse.SerializeToString,
            ),
            'unregisterStorageLocation': grpc.unary_unary_rpc_method_handler(
                    servicer.unregisterStorageLocation,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.UnregisterStorageLocationRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'unregisterExecutionEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.unregisterExecutionEnvironment,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.UnregisterExecutionEnvironmentRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'checkAlive': grpc.unary_unary_rpc_method_handler(
                    servicer.checkAlive,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'notifyExecutionEnvironmentShutdown': grpc.unary_unary_rpc_method_handler(
                    servicer.notifyExecutionEnvironmentShutdown,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.NotifyExecutionEnvironmentShutdownRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'notifyStorageLocationShutdown': grpc.unary_unary_rpc_method_handler(
                    servicer.notifyStorageLocationShutdown,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.NotifyStorageLocationShutdownRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'existsActiveEnvironmentsForSL': grpc.unary_unary_rpc_method_handler(
                    servicer.existsActiveEnvironmentsForSL,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.ExistsActiveEnvironmentsForSLRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.ExistsActiveEnvironmentsForSLResponse.SerializeToString,
            ),
            'performSetOfNewAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.performSetOfNewAccounts,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.PerformSetAccountsRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.PerformSetAccountsResponse.SerializeToString,
            ),
            'performSetOfOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.performSetOfOperations,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.PerformSetOperationsRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.PerformSetOperationsResponse.SerializeToString,
            ),
            'publishAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.publishAddress,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.PublishAddressRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'newAccountNoAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.newAccountNoAdmin,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.NewAccountNoAdminRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.NewAccountResponse.SerializeToString,
            ),
            'newAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.newAccount,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.NewAccountRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.NewAccountResponse.SerializeToString,
            ),
            'getAccountID': grpc.unary_unary_rpc_method_handler(
                    servicer.getAccountID,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetAccountIDRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetAccountIDResponse.SerializeToString,
            ),
            'getAccountList': grpc.unary_unary_rpc_method_handler(
                    servicer.getAccountList,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetAccountListRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetAccountListResponse.SerializeToString,
            ),
            'newSession': grpc.unary_unary_rpc_method_handler(
                    servicer.newSession,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.NewSessionRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.NewSessionResponse.SerializeToString,
            ),
            'getInfoOfSessionForDS': grpc.unary_unary_rpc_method_handler(
                    servicer.getInfoOfSessionForDS,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetInfoOfSessionForDSRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetInfoOfSessionForDSResponse.SerializeToString,
            ),
            'newNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.newNamespace,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.NewNamespaceRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.NewNamespaceResponse.SerializeToString,
            ),
            'removeNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.removeNamespace,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.RemoveNamespaceRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getNamespaceID': grpc.unary_unary_rpc_method_handler(
                    servicer.getNamespaceID,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetNamespaceIDRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetNamespaceIDResponse.SerializeToString,
            ),
            'getNamespaceLang': grpc.unary_unary_rpc_method_handler(
                    servicer.getNamespaceLang,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetNamespaceLangRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetNamespaceLangResponse.SerializeToString,
            ),
            'getObjectDataSetID': grpc.unary_unary_rpc_method_handler(
                    servicer.getObjectDataSetID,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetObjectDataSetIDRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetObjectDataSetIDResponse.SerializeToString,
            ),
            'importInterface': grpc.unary_unary_rpc_method_handler(
                    servicer.importInterface,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.ImportInterfaceRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'importContract': grpc.unary_unary_rpc_method_handler(
                    servicer.importContract,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.ImportContractRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getInfoOfClassesInNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.getInfoOfClassesInNamespace,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetInfoOfClassesInNamespaceRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetInfoOfClassesInNamespaceResponse.SerializeToString,
            ),
            'getImportedClassesInfoInNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.getImportedClassesInfoInNamespace,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetImportedClassesInfoInNamespaceRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetImportedClassesInfoInNamespaceResponse.SerializeToString,
            ),
            'getClassIDfromImport': grpc.unary_unary_rpc_method_handler(
                    servicer.getClassIDfromImport,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetClassIDFromImportRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetClassIDFromImportResponse.SerializeToString,
            ),
            'getNamespaces': grpc.unary_unary_rpc_method_handler(
                    servicer.getNamespaces,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetNamespacesRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetNamespacesResponse.SerializeToString,
            ),
            'newDataSet': grpc.unary_unary_rpc_method_handler(
                    servicer.newDataSet,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.NewDataSetRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.NewDataSetResponse.SerializeToString,
            ),
            'removeDataSet': grpc.unary_unary_rpc_method_handler(
                    servicer.removeDataSet,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.RemoveDataSetRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getDataSetID': grpc.unary_unary_rpc_method_handler(
                    servicer.getDataSetID,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetDataSetIDRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetDataSetIDResponse.SerializeToString,
            ),
            'checkDataSetIsPublic': grpc.unary_unary_rpc_method_handler(
                    servicer.checkDataSetIsPublic,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.CheckDataSetIsPublicRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.CheckDataSetIsPublicResponse.SerializeToString,
            ),
            'getPublicDataSets': grpc.unary_unary_rpc_method_handler(
                    servicer.getPublicDataSets,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetPublicDataSetsRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetPublicDataSetsResponse.SerializeToString,
            ),
            'getAccountDataSets': grpc.unary_unary_rpc_method_handler(
                    servicer.getAccountDataSets,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetAccountDataSetsRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetAccountDataSetsResponse.SerializeToString,
            ),
            'newClass': grpc.unary_unary_rpc_method_handler(
                    servicer.newClass,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.NewClassRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.NewClassResponse.SerializeToString,
            ),
            'removeClass': grpc.unary_unary_rpc_method_handler(
                    servicer.removeClass,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.RemoveClassRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'removeOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.removeOperation,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.RemoveOperationRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'removeImplementation': grpc.unary_unary_rpc_method_handler(
                    servicer.removeImplementation,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.RemoveImplementationRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getOperationID': grpc.unary_unary_rpc_method_handler(
                    servicer.getOperationID,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetOperationIDRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetOperationIDResponse.SerializeToString,
            ),
            'getPropertyID': grpc.unary_unary_rpc_method_handler(
                    servicer.getPropertyID,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetPropertyIDRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetPropertyIDResponse.SerializeToString,
            ),
            'getClassID': grpc.unary_unary_rpc_method_handler(
                    servicer.getClassID,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetClassIDRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetClassIDResponse.SerializeToString,
            ),
            'getClassInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.getClassInfo,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetClassInfoRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetClassInfoResponse.SerializeToString,
            ),
            'newContract': grpc.unary_unary_rpc_method_handler(
                    servicer.newContract,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.NewContractRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.NewContractResponse.SerializeToString,
            ),
            'registerToPublicContract': grpc.unary_unary_rpc_method_handler(
                    servicer.registerToPublicContract,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.RegisterToPublicContractRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'registerToPublicContractOfNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.registerToPublicContractOfNamespace,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.RegisterToPublicContractOfNamespaceRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.RegisterToPublicContractOfNamespaceResponse.SerializeToString,
            ),
            'getContractIDsOfApplicant': grpc.unary_unary_rpc_method_handler(
                    servicer.getContractIDsOfApplicant,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetContractIDsOfApplicantRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetContractIDsOfApplicantResponse.SerializeToString,
            ),
            'getContractIDsOfProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.getContractIDsOfProvider,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetContractIDsOfProviderRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetContractIDsOfProviderResponse.SerializeToString,
            ),
            'getContractIDsOfApplicantWithProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.getContractIDsOfApplicantWithProvider,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetContractsOfApplicantWithProvRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetContractsOfApplicantWithProvResponse.SerializeToString,
            ),
            'newDataContract': grpc.unary_unary_rpc_method_handler(
                    servicer.newDataContract,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.NewDataContractRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.NewDataContractResponse.SerializeToString,
            ),
            'registerToPublicDataContract': grpc.unary_unary_rpc_method_handler(
                    servicer.registerToPublicDataContract,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.RegisterToPublicDataContractRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getDataContractIDsOfApplicant': grpc.unary_unary_rpc_method_handler(
                    servicer.getDataContractIDsOfApplicant,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetDataContractIDsOfApplicantRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetDataContractIDsOfApplicantResponse.SerializeToString,
            ),
            'getDataContractIDsOfProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.getDataContractIDsOfProvider,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetDataContractIDsOfProviderRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetDataContractIDsOfProviderResponse.SerializeToString,
            ),
            'getDataContractInfoOfApplicantWithProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.getDataContractInfoOfApplicantWithProvider,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetDataContractInfoOfApplicantWithProvRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetDataContractInfoOfApplicantWithProvResponse.SerializeToString,
            ),
            'newInterface': grpc.unary_unary_rpc_method_handler(
                    servicer.newInterface,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.NewInterfaceRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.NewInterfaceResponse.SerializeToString,
            ),
            'getInterfaceInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.getInterfaceInfo,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetInterfaceInfoRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetInterfaceInfoResponse.SerializeToString,
            ),
            'removeInterface': grpc.unary_unary_rpc_method_handler(
                    servicer.removeInterface,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.RemoveInterfaceRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getAllExecutionEnvironmentsInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.getAllExecutionEnvironmentsInfo,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetAllExecutionEnvironmentsInfoRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetAllExecutionEnvironmentsInfoResponse.SerializeToString,
            ),
            'getStorageLocationID': grpc.unary_unary_rpc_method_handler(
                    servicer.getStorageLocationID,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetStorageLocationIDRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetStorageLocationIDResponse.SerializeToString,
            ),
            'getStorageLocationInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.getStorageLocationInfo,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetStorageLocationInfoRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetStorageLocationInfoResponse.SerializeToString,
            ),
            'getExecutionEnvironmentInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.getExecutionEnvironmentInfo,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetExecutionEnvironmentInfoRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetExecutionEnvironmentInfoResponse.SerializeToString,
            ),
            'getObjectInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.getObjectInfo,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetObjectInfoRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetObjectInfoResponse.SerializeToString,
            ),
            'getObjectFromAlias': grpc.unary_unary_rpc_method_handler(
                    servicer.getObjectFromAlias,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetObjectFromAliasRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetObjectFromAliasResponse.SerializeToString,
            ),
            'deleteAlias': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteAlias,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.DeleteAliasRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.DeleteAliasResponse.SerializeToString,
            ),
            'getObjectsMetaDataInfoOfClassForNM': grpc.unary_unary_rpc_method_handler(
                    servicer.getObjectsMetaDataInfoOfClassForNM,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetObjectsMetaDataInfoOfClassForNMRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetObjectsMetaDataInfoOfClassForNMResponse.SerializeToString,
            ),
            'addAlias': grpc.unary_unary_rpc_method_handler(
                    servicer.addAlias,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.AddAliasRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'registerObjectFromGC': grpc.unary_unary_rpc_method_handler(
                    servicer.registerObjectFromGC,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.RegisterObjectForGCRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'unregisterObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.unregisterObjects,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.UnregisterObjectsRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'registerObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.registerObjects,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.RegisterObjectsRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.RegisterObjectsResponse.SerializeToString,
            ),
            'setDataSetIDFromGarbageCollector': grpc.unary_unary_rpc_method_handler(
                    servicer.setDataSetIDFromGarbageCollector,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.SetDataSetIDFromGarbageCollectorRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getMetadataByOID': grpc.unary_unary_rpc_method_handler(
                    servicer.getMetadataByOID,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetMetadataByOIDRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetMetadataByOIDResponse.SerializeToString,
            ),
            'getNumObjects': grpc.unary_unary_rpc_method_handler(
                    servicer.getNumObjects,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.GetNumObjectsResponse.SerializeToString,
            ),
            'setDataSetID': grpc.unary_unary_rpc_method_handler(
                    servicer.setDataSetID,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.SetDataSetIDRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'moveObject': grpc.unary_unary_rpc_method_handler(
                    servicer.moveObject,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.MoveObjectRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.MoveObjectResponse.SerializeToString,
            ),
            'setObjectReadOnly': grpc.unary_unary_rpc_method_handler(
                    servicer.setObjectReadOnly,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.SetObjectReadOnlyRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'setObjectReadWrite': grpc.unary_unary_rpc_method_handler(
                    servicer.setObjectReadWrite,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.SetObjectReadWriteRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'executeImplementation': grpc.unary_unary_rpc_method_handler(
                    servicer.executeImplementation,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.ExecuteImplementationRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.ExecuteImplementationResponse.SerializeToString,
            ),
            'executeMethodOnTarget': grpc.unary_unary_rpc_method_handler(
                    servicer.executeMethodOnTarget,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.ExecuteMethodOnTargetRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.ExecuteMethodOnTargetResponse.SerializeToString,
            ),
            'getDataClayID': grpc.unary_unary_rpc_method_handler(
                    servicer.getDataClayID,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetDataClayIDResponse.SerializeToString,
            ),
            'registerExternalDataClay': grpc.unary_unary_rpc_method_handler(
                    servicer.registerExternalDataClay,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.RegisterExternalDataClayRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.RegisterExternalDataClayResponse.SerializeToString,
            ),
            'registerExternalDataClayOverrideAuthority': grpc.unary_unary_rpc_method_handler(
                    servicer.registerExternalDataClayOverrideAuthority,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.RegisterExternalDataClayOverrideAuthorityRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.RegisterExternalDataClayResponse.SerializeToString,
            ),
            'notifyRegistrationOfExternalDataClay': grpc.unary_unary_rpc_method_handler(
                    servicer.notifyRegistrationOfExternalDataClay,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.NotifyRegistrationOfExternalDataClayRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.NotifyRegistrationOfExternalDataClayResponse.SerializeToString,
            ),
            'getExternalDataClayInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.getExternalDataClayInfo,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetExtDataClayInfoRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetExtDataClayInfoResponse.SerializeToString,
            ),
            'getExternalDataclayId': grpc.unary_unary_rpc_method_handler(
                    servicer.getExternalDataclayId,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetExternalDataclayIDRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetExternalDataclayIDResponse.SerializeToString,
            ),
            'getClassesInNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.getClassesInNamespace,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetClassesInNamespaceRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetClassesInNamespaceResponse.SerializeToString,
            ),
            'importModelsFromExternalDataClay': grpc.unary_unary_rpc_method_handler(
                    servicer.importModelsFromExternalDataClay,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.ImportModelsFromExternalDataClayRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getStubs': grpc.unary_unary_rpc_method_handler(
                    servicer.getStubs,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetStubsRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetStubsResponse.SerializeToString,
            ),
            'getBabelStubs': grpc.unary_unary_rpc_method_handler(
                    servicer.getBabelStubs,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetBabelStubsRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetBabelStubsResponse.SerializeToString,
            ),
            'registerECA': grpc.unary_unary_rpc_method_handler(
                    servicer.registerECA,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.RegisterECARequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'adviseEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.adviseEvent,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.AdviseEventRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'isPrefetchingEnabled': grpc.unary_unary_rpc_method_handler(
                    servicer.isPrefetchingEnabled,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.IsPrefetchingEnabledResponse.SerializeToString,
            ),
            'getClassNameForDS': grpc.unary_unary_rpc_method_handler(
                    servicer.getClassNameForDS,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetClassNameForDSRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetClassNameForDSResponse.SerializeToString,
            ),
            'getClassNameAndNamespaceForDS': grpc.unary_unary_rpc_method_handler(
                    servicer.getClassNameAndNamespaceForDS,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetClassNameAndNamespaceForDSRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetClassNameAndNamespaceForDSResponse.SerializeToString,
            ),
            'getContractIDOfDataClayProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.getContractIDOfDataClayProvider,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetContractIDOfDataClayProviderRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetContractIDOfDataClayProviderResponse.SerializeToString,
            ),
            'objectExistsInDataClay': grpc.unary_unary_rpc_method_handler(
                    servicer.objectExistsInDataClay,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.ObjectExistsInDataClayRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.ObjectExistsInDataClayResponse.SerializeToString,
            ),
            'closeSession': grpc.unary_unary_rpc_method_handler(
                    servicer.closeSession,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.CloseSessionRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getMetadataByOIDForDS': grpc.unary_unary_rpc_method_handler(
                    servicer.getMetadataByOIDForDS,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.GetMetadataByOIDForDSRequest.FromString,
                    response_serializer=protos_dot_logicmodule__messages__pb2.GetMetadataByOIDForDSResponse.SerializeToString,
            ),
            'activateTracing': grpc.unary_unary_rpc_method_handler(
                    servicer.activateTracing,
                    request_deserializer=protos_dot_logicmodule__messages__pb2.ActivateTracingRequest.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'deactivateTracing': grpc.unary_unary_rpc_method_handler(
                    servicer.deactivateTracing,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'getTraces': grpc.unary_unary_rpc_method_handler(
                    servicer.getTraces,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.GetTracesResponse.SerializeToString,
            ),
            'cleanMetaDataCaches': grpc.unary_unary_rpc_method_handler(
                    servicer.cleanMetaDataCaches,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'closeManagerDb': grpc.unary_unary_rpc_method_handler(
                    servicer.closeManagerDb,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
            'closeDb': grpc.unary_unary_rpc_method_handler(
                    servicer.closeDb,
                    request_deserializer=protos_dot_common__messages__pb2.EmptyMessage.FromString,
                    response_serializer=protos_dot_common__messages__pb2.ExceptionInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protos.logicmodule.LogicModule', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LogicModule(object):
    """Interface exported by the server.
    """

    @staticmethod
    def autoregisterSL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/autoregisterSL',
            protos_dot_logicmodule__messages__pb2.AutoRegisterSLRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def autoregisterEE(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/autoregisterEE',
            protos_dot_logicmodule__messages__pb2.AutoRegisterEERequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.AutoRegisterEEResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def unregisterStorageLocation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/unregisterStorageLocation',
            protos_dot_logicmodule__messages__pb2.UnregisterStorageLocationRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def unregisterExecutionEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/unregisterExecutionEnvironment',
            protos_dot_logicmodule__messages__pb2.UnregisterExecutionEnvironmentRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def checkAlive(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/checkAlive',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def notifyExecutionEnvironmentShutdown(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/notifyExecutionEnvironmentShutdown',
            protos_dot_logicmodule__messages__pb2.NotifyExecutionEnvironmentShutdownRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def notifyStorageLocationShutdown(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/notifyStorageLocationShutdown',
            protos_dot_logicmodule__messages__pb2.NotifyStorageLocationShutdownRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def existsActiveEnvironmentsForSL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/existsActiveEnvironmentsForSL',
            protos_dot_logicmodule__messages__pb2.ExistsActiveEnvironmentsForSLRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.ExistsActiveEnvironmentsForSLResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def performSetOfNewAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/performSetOfNewAccounts',
            protos_dot_logicmodule__messages__pb2.PerformSetAccountsRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.PerformSetAccountsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def performSetOfOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/performSetOfOperations',
            protos_dot_logicmodule__messages__pb2.PerformSetOperationsRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.PerformSetOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def publishAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/publishAddress',
            protos_dot_logicmodule__messages__pb2.PublishAddressRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def newAccountNoAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/newAccountNoAdmin',
            protos_dot_logicmodule__messages__pb2.NewAccountNoAdminRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.NewAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def newAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/newAccount',
            protos_dot_logicmodule__messages__pb2.NewAccountRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.NewAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getAccountID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getAccountID',
            protos_dot_logicmodule__messages__pb2.GetAccountIDRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetAccountIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getAccountList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getAccountList',
            protos_dot_logicmodule__messages__pb2.GetAccountListRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetAccountListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def newSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/newSession',
            protos_dot_logicmodule__messages__pb2.NewSessionRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.NewSessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getInfoOfSessionForDS(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getInfoOfSessionForDS',
            protos_dot_logicmodule__messages__pb2.GetInfoOfSessionForDSRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetInfoOfSessionForDSResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def newNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/newNamespace',
            protos_dot_logicmodule__messages__pb2.NewNamespaceRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.NewNamespaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def removeNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/removeNamespace',
            protos_dot_logicmodule__messages__pb2.RemoveNamespaceRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getNamespaceID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getNamespaceID',
            protos_dot_logicmodule__messages__pb2.GetNamespaceIDRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetNamespaceIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getNamespaceLang(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getNamespaceLang',
            protos_dot_logicmodule__messages__pb2.GetNamespaceLangRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetNamespaceLangResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getObjectDataSetID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getObjectDataSetID',
            protos_dot_logicmodule__messages__pb2.GetObjectDataSetIDRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetObjectDataSetIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def importInterface(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/importInterface',
            protos_dot_logicmodule__messages__pb2.ImportInterfaceRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def importContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/importContract',
            protos_dot_logicmodule__messages__pb2.ImportContractRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getInfoOfClassesInNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getInfoOfClassesInNamespace',
            protos_dot_logicmodule__messages__pb2.GetInfoOfClassesInNamespaceRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetInfoOfClassesInNamespaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getImportedClassesInfoInNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getImportedClassesInfoInNamespace',
            protos_dot_logicmodule__messages__pb2.GetImportedClassesInfoInNamespaceRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetImportedClassesInfoInNamespaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getClassIDfromImport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getClassIDfromImport',
            protos_dot_logicmodule__messages__pb2.GetClassIDFromImportRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetClassIDFromImportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getNamespaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getNamespaces',
            protos_dot_logicmodule__messages__pb2.GetNamespacesRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetNamespacesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def newDataSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/newDataSet',
            protos_dot_logicmodule__messages__pb2.NewDataSetRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.NewDataSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def removeDataSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/removeDataSet',
            protos_dot_logicmodule__messages__pb2.RemoveDataSetRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getDataSetID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getDataSetID',
            protos_dot_logicmodule__messages__pb2.GetDataSetIDRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetDataSetIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def checkDataSetIsPublic(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/checkDataSetIsPublic',
            protos_dot_logicmodule__messages__pb2.CheckDataSetIsPublicRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.CheckDataSetIsPublicResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getPublicDataSets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getPublicDataSets',
            protos_dot_logicmodule__messages__pb2.GetPublicDataSetsRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetPublicDataSetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getAccountDataSets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getAccountDataSets',
            protos_dot_logicmodule__messages__pb2.GetAccountDataSetsRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetAccountDataSetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def newClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/newClass',
            protos_dot_logicmodule__messages__pb2.NewClassRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.NewClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def removeClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/removeClass',
            protos_dot_logicmodule__messages__pb2.RemoveClassRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def removeOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/removeOperation',
            protos_dot_logicmodule__messages__pb2.RemoveOperationRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def removeImplementation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/removeImplementation',
            protos_dot_logicmodule__messages__pb2.RemoveImplementationRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getOperationID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getOperationID',
            protos_dot_logicmodule__messages__pb2.GetOperationIDRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetOperationIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getPropertyID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getPropertyID',
            protos_dot_logicmodule__messages__pb2.GetPropertyIDRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetPropertyIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getClassID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getClassID',
            protos_dot_logicmodule__messages__pb2.GetClassIDRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetClassIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getClassInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getClassInfo',
            protos_dot_logicmodule__messages__pb2.GetClassInfoRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetClassInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def newContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/newContract',
            protos_dot_logicmodule__messages__pb2.NewContractRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.NewContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerToPublicContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/registerToPublicContract',
            protos_dot_logicmodule__messages__pb2.RegisterToPublicContractRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerToPublicContractOfNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/registerToPublicContractOfNamespace',
            protos_dot_logicmodule__messages__pb2.RegisterToPublicContractOfNamespaceRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.RegisterToPublicContractOfNamespaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getContractIDsOfApplicant(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getContractIDsOfApplicant',
            protos_dot_logicmodule__messages__pb2.GetContractIDsOfApplicantRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetContractIDsOfApplicantResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getContractIDsOfProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getContractIDsOfProvider',
            protos_dot_logicmodule__messages__pb2.GetContractIDsOfProviderRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetContractIDsOfProviderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getContractIDsOfApplicantWithProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getContractIDsOfApplicantWithProvider',
            protos_dot_logicmodule__messages__pb2.GetContractsOfApplicantWithProvRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetContractsOfApplicantWithProvResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def newDataContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/newDataContract',
            protos_dot_logicmodule__messages__pb2.NewDataContractRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.NewDataContractResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerToPublicDataContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/registerToPublicDataContract',
            protos_dot_logicmodule__messages__pb2.RegisterToPublicDataContractRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getDataContractIDsOfApplicant(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getDataContractIDsOfApplicant',
            protos_dot_logicmodule__messages__pb2.GetDataContractIDsOfApplicantRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetDataContractIDsOfApplicantResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getDataContractIDsOfProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getDataContractIDsOfProvider',
            protos_dot_logicmodule__messages__pb2.GetDataContractIDsOfProviderRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetDataContractIDsOfProviderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getDataContractInfoOfApplicantWithProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getDataContractInfoOfApplicantWithProvider',
            protos_dot_logicmodule__messages__pb2.GetDataContractInfoOfApplicantWithProvRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetDataContractInfoOfApplicantWithProvResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def newInterface(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/newInterface',
            protos_dot_logicmodule__messages__pb2.NewInterfaceRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.NewInterfaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getInterfaceInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getInterfaceInfo',
            protos_dot_logicmodule__messages__pb2.GetInterfaceInfoRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetInterfaceInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def removeInterface(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/removeInterface',
            protos_dot_logicmodule__messages__pb2.RemoveInterfaceRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getAllExecutionEnvironmentsInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getAllExecutionEnvironmentsInfo',
            protos_dot_logicmodule__messages__pb2.GetAllExecutionEnvironmentsInfoRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetAllExecutionEnvironmentsInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getStorageLocationID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getStorageLocationID',
            protos_dot_logicmodule__messages__pb2.GetStorageLocationIDRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetStorageLocationIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getStorageLocationInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getStorageLocationInfo',
            protos_dot_logicmodule__messages__pb2.GetStorageLocationInfoRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetStorageLocationInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getExecutionEnvironmentInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getExecutionEnvironmentInfo',
            protos_dot_logicmodule__messages__pb2.GetExecutionEnvironmentInfoRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetExecutionEnvironmentInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getObjectInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getObjectInfo',
            protos_dot_logicmodule__messages__pb2.GetObjectInfoRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetObjectInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getObjectFromAlias(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getObjectFromAlias',
            protos_dot_logicmodule__messages__pb2.GetObjectFromAliasRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetObjectFromAliasResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteAlias(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/deleteAlias',
            protos_dot_logicmodule__messages__pb2.DeleteAliasRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.DeleteAliasResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getObjectsMetaDataInfoOfClassForNM(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getObjectsMetaDataInfoOfClassForNM',
            protos_dot_logicmodule__messages__pb2.GetObjectsMetaDataInfoOfClassForNMRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetObjectsMetaDataInfoOfClassForNMResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def addAlias(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/addAlias',
            protos_dot_logicmodule__messages__pb2.AddAliasRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerObjectFromGC(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/registerObjectFromGC',
            protos_dot_logicmodule__messages__pb2.RegisterObjectForGCRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def unregisterObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/unregisterObjects',
            protos_dot_logicmodule__messages__pb2.UnregisterObjectsRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/registerObjects',
            protos_dot_logicmodule__messages__pb2.RegisterObjectsRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.RegisterObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def setDataSetIDFromGarbageCollector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/setDataSetIDFromGarbageCollector',
            protos_dot_logicmodule__messages__pb2.SetDataSetIDFromGarbageCollectorRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getMetadataByOID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getMetadataByOID',
            protos_dot_logicmodule__messages__pb2.GetMetadataByOIDRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetMetadataByOIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getNumObjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getNumObjects',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.GetNumObjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def setDataSetID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/setDataSetID',
            protos_dot_logicmodule__messages__pb2.SetDataSetIDRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def moveObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/moveObject',
            protos_dot_logicmodule__messages__pb2.MoveObjectRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.MoveObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def setObjectReadOnly(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/setObjectReadOnly',
            protos_dot_logicmodule__messages__pb2.SetObjectReadOnlyRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def setObjectReadWrite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/setObjectReadWrite',
            protos_dot_logicmodule__messages__pb2.SetObjectReadWriteRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def executeImplementation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/executeImplementation',
            protos_dot_logicmodule__messages__pb2.ExecuteImplementationRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.ExecuteImplementationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def executeMethodOnTarget(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/executeMethodOnTarget',
            protos_dot_logicmodule__messages__pb2.ExecuteMethodOnTargetRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.ExecuteMethodOnTargetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getDataClayID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getDataClayID',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetDataClayIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerExternalDataClay(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/registerExternalDataClay',
            protos_dot_logicmodule__messages__pb2.RegisterExternalDataClayRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.RegisterExternalDataClayResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerExternalDataClayOverrideAuthority(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/registerExternalDataClayOverrideAuthority',
            protos_dot_logicmodule__messages__pb2.RegisterExternalDataClayOverrideAuthorityRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.RegisterExternalDataClayResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def notifyRegistrationOfExternalDataClay(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/notifyRegistrationOfExternalDataClay',
            protos_dot_logicmodule__messages__pb2.NotifyRegistrationOfExternalDataClayRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.NotifyRegistrationOfExternalDataClayResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getExternalDataClayInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getExternalDataClayInfo',
            protos_dot_logicmodule__messages__pb2.GetExtDataClayInfoRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetExtDataClayInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getExternalDataclayId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getExternalDataclayId',
            protos_dot_logicmodule__messages__pb2.GetExternalDataclayIDRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetExternalDataclayIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getClassesInNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getClassesInNamespace',
            protos_dot_logicmodule__messages__pb2.GetClassesInNamespaceRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetClassesInNamespaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def importModelsFromExternalDataClay(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/importModelsFromExternalDataClay',
            protos_dot_logicmodule__messages__pb2.ImportModelsFromExternalDataClayRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getStubs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getStubs',
            protos_dot_logicmodule__messages__pb2.GetStubsRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetStubsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getBabelStubs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getBabelStubs',
            protos_dot_logicmodule__messages__pb2.GetBabelStubsRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetBabelStubsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def registerECA(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/registerECA',
            protos_dot_logicmodule__messages__pb2.RegisterECARequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def adviseEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/adviseEvent',
            protos_dot_logicmodule__messages__pb2.AdviseEventRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def isPrefetchingEnabled(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/isPrefetchingEnabled',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_logicmodule__messages__pb2.IsPrefetchingEnabledResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getClassNameForDS(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getClassNameForDS',
            protos_dot_logicmodule__messages__pb2.GetClassNameForDSRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetClassNameForDSResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getClassNameAndNamespaceForDS(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getClassNameAndNamespaceForDS',
            protos_dot_logicmodule__messages__pb2.GetClassNameAndNamespaceForDSRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetClassNameAndNamespaceForDSResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getContractIDOfDataClayProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getContractIDOfDataClayProvider',
            protos_dot_logicmodule__messages__pb2.GetContractIDOfDataClayProviderRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetContractIDOfDataClayProviderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def objectExistsInDataClay(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/objectExistsInDataClay',
            protos_dot_logicmodule__messages__pb2.ObjectExistsInDataClayRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.ObjectExistsInDataClayResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def closeSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/closeSession',
            protos_dot_logicmodule__messages__pb2.CloseSessionRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getMetadataByOIDForDS(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getMetadataByOIDForDS',
            protos_dot_logicmodule__messages__pb2.GetMetadataByOIDForDSRequest.SerializeToString,
            protos_dot_logicmodule__messages__pb2.GetMetadataByOIDForDSResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def activateTracing(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/activateTracing',
            protos_dot_logicmodule__messages__pb2.ActivateTracingRequest.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deactivateTracing(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/deactivateTracing',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getTraces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/getTraces',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.GetTracesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def cleanMetaDataCaches(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/cleanMetaDataCaches',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def closeManagerDb(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/closeManagerDb',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def closeDb(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protos.logicmodule.LogicModule/closeDb',
            protos_dot_common__messages__pb2.EmptyMessage.SerializeToString,
            protos_dot_common__messages__pb2.ExceptionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
